/*  Copyright (C) MOXA Inc. All rights reserved.

    This software is distributed under the terms of the
    MOXA License.  See the file COPYING-MOXA for details. 

    This software is referenced by msdn 
    http://msdn2.microsoft.com/en-us/library/ms838476.aspx#ewfapiv3
*/

#include "stdafx.h"
#include <stdio.h>
#include <windows.h>
#include "ewfapi.h"

void DisplayHelp();

int _tmain(int argc, _TCHAR* argv[])
{
	HANDLE hDisk;
	WCHAR szDrive[20];
	DWORD dwStatus = ERROR_SUCCESS;
	BOOL bResult =FALSE;
      
	wprintf(L"\nEWFCMD - EWF API Example\n");
	wprintf(L"Copyright (c) 2003 A7 Engineering\n\n");

	 //The IF statement holds the main body of the application.
   //The IF statement checks to make sure that command-prompt
   //arguments are correct. If the command-prompt arguments are
   //incorrect, display Help.

   if (   (argc == 3)
   &&   (L'-' == argv[2][0]))
   {
   
      //Open the handle to the volume and check whether the
      //volume is valid.
      //First step is to put the drive parameter in the correct
      //format:
      swprintf(szDrive, L"\\\\.\\%s", argv[1]);
      
      //Next, open the handle and check for errors.
      hDisk = EwfMgrOpenProtected(szDrive);
      if (INVALID_HANDLE_VALUE == hDisk) 
      {
         wprintf(L"Invalid Handle. Please make sure that the drive exists\n");
         DisplayHelp();
         return 1;
      }
      
      //The switch statement is based on the second parameter to
      //carry out the action to perform on the volume handle.
      //Look at the second character of the second argument to
      //perform the specific EWF operation.
      switch (argv[2][1])
         {
         
         //E for Enable EWF
         case 'E':
            {
               
               bResult = EwfMgrEnable(hDisk);
               if (!bResult)
               {
                  dwStatus = GetLastError();
                  wprintf(L"EwfMgrEnable failed LE = %u\n",dwStatus);
                  EwfMgrClose(hDisk);
                  return 1;
               }
                    
               wprintf(L"EWF Enabled - ");
               wprintf(L"Reboot system for change to take effect\n");
               EwfMgrClose(hDisk);
            }
            break;
         
         //D for Disable EWF
         case 'D' :
            {
               //For EWF RAM REG configurations, the
               //second parameter (commit) must be
               //TRUE. This will commit the EWF RAM REG
               //disable state, which is required to
               //disable the EWF RAM REG configuration.
               
               bResult = EwfMgrDisable(hDisk,FALSE);
               if (!bResult)
               {
                  dwStatus = GetLastError();
                  wprintf(L"EwfMgrDisable failed LE = %u\n",dwStatus);
                  EwfMgrClose(hDisk);
                  return 1;
               }
                    
               wprintf(L"EWF Disabled - ");
               wprintf(L"Reboot system for change to take effect\n");
               EwfMgrClose(hDisk);
            }
            break;
         
         //C for Commit changes to protected volume
         case 'C' :
            {
               bResult = EwfMgrCommit(hDisk);
               if (!bResult)
               {
                  dwStatus = GetLastError();
                  wprintf(L"EwfMgrCommit failed LE = %u\n",dwStatus);
                  EwfMgrClose(hDisk);
                  return 1;
               }
                    
               wprintf(L"Changes commited - ");
               wprintf(L"Reboot system for change to take effect\n");
               EwfMgrClose(hDisk);
            }
            break;

         default:
            DisplayHelp();
            return 1;
         }
   }
   else
   {
      //If the parameter conditions fail, display Help.
      DisplayHelp();
      return 1;
   }


	return 0;
}

void DisplayHelp()
{
   wprintf(L"\nEWFCMD <Drive> <Option>\n");
   wprintf(L"-E Enable EWF\n");
   wprintf(L"-D Disable EWF\n");
   wprintf(L"-C Commit Changes to Protect Volume\n");
}
